@@ -332,7 +332,6 @@ class CaperRunner(CaperBase):
                 Input JSON file itself will still be localized.
             fileobj_stdout:
                 File-like object to write Cromwell's STDOUT.
-                Note that STDERR is redirected to STDOUT.
             fileobj_troubleshoot:
                 File-like object to write auto-troubleshooting after workflow is done.
             work_dir:
@@ -452,6 +451,7 @@ class CaperRunner(CaperBase):
         fileobj_stdout=None,
         embed_subworkflow=False,
         java_heap_server=Cromwell.DEFAULT_JAVA_HEAP_CROMWELL_SERVER,
+        auto_update_metadata=True,
         work_dir=None,
         dry_run=False,
     ):
@@ -477,7 +477,6 @@ class CaperRunner(CaperBase):
                 Backend config file (HOCON) to override Caper's auto-generated backend config.
             fileobj_stdout:
                 File-like object to write Cromwell's STDOUT.
-                Note that STDERR is redirected to STDOUT.
             embed_subworkflow:
                 Caper stores/updates metadata.JSON file on
                 each workflow's root directory whenever there is status change
@@ -487,6 +486,8 @@ class CaperRunner(CaperBase):
                 This is to mimic behavior of Cromwell run mode's -m parameter.
             java_heap_server:
                 Java heap (java -Xmx) for Cromwell server mode.
+            auto_update_metadata:
+                Automatic retrieval/writing of metadata.json upon workflow/task's status change.
             work_dir:
                 Local temporary directory to store all temporary files.
                 Temporary files mean intermediate files used for running Cromwell.
@@ -516,6 +517,8 @@ class CaperRunner(CaperBase):
             server_heartbeat=server_heartbeat,
             fileobj_stdout=fileobj_stdout,
             embed_subworkflow=embed_subworkflow,
+            java_heap_cromwell_server=java_heap_server,
+            auto_update_metadata=auto_update_metadata,
             dry_run=dry_run,
         )
         return th
